#!/usr/bin/env python

##############################################################################
##
## Copyright (C) 2021 Narda Safety Test Solutions GmbH.
## Contact: www.narda-sts.com
##
## Redistribution and use in source and binary forms,
## with or without modification, are permitted provided that the following
## conditions are met:
##
## 1.) Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2.) Redistributions in binary form must reproduce the above copyright
## notice, this list of conditions and the following disclaimer in the
## documentation and/or other materials provided with the distribution.
##
## 3.) Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from this
## software without specific prior written permission.
##
## 4.) EXPORT CONTROL
## The Software, including technical data /cryptographic software,
## may be subject to, German, European Union and U.S. export controls and
## may be subject to import or export controls in other countries.
## The Licensee agrees to strictly comply with all applicable import and
## export regulations. He specifically agrees, that he must not disclose or
## otherwise export or re-export the Licensed Software or any part thereof
## delivered under this end user license agreement (EULA) to any country
## (including a national or resident of such country) without a valid export
## or import license. Please be aware that the Software may contain
## US-Content, therefor the Licensee represent and warrant that he is not a
## citizen of, or otherwise located within, an embargoed nation (including
## without limitation Iran, Syria, Sudan, Cuba, North Korea) and that he is
## not otherwise prohibited under the Export Laws from receiving the Software.
## All rights to Use the Software are granted on condition that such rights
## are forfeited if the Licensee fails to comply with
## the terms of this Agreement.
##
## 5.) SEVERABILITY
## Should any provision of this Agreement be or become invalid, ineffective
## or unenforceable, the remaining provisions of this Agreement shall be
## valid. The parties agree to replace the invalid, ineffective or
## unenforceable provision by a valid, effective and enforceable provision
## which best meets the commercial intention of the parties.
## The same shall apply in case of omissions.
##
## 6.) APPLICABLE LAW AND PLACE OF JURISTICATION
## This Agreement shall be constituted under the law of Germany.
## The United Nations Convention on the International Sale of Goods
## shall not apply to this Agreement. The Place of Jurisdiction for any
## dispute between the Parties shall be Tübingen (Germany).
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
## PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Narda Safety Test Solutions GmbH
## BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
## CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
## SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
## INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
## CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
## ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
##
##############################################################################


import sys
import os
from pathlib import Path
import wx
import time
import datetime as dt
import numpy as np
from PIL import ImageGrab, Image, ImageFile
import jinja2
from docx.enum.style import WD_STYLE_TYPE
from nardascripting.base.usrscriptbase import *
from nardascripting.base.signalsharkdev import *
from nardascripting.base.measthread import MeasDlgThread
from nardascripting.base.toolbox import ListMsgBox
import nardascripting.base.toolbox as tb
from .gui.mdocdlgs import *
from .gui.mdocdlgsbase import *
from .basedata import *
from io import FileIO
from docx import Document
from docx.shared import Inches, Cm
from docx.enum.table import WD_TABLE_DIRECTION
from docx.enum.text import WD_PARAGRAPH_ALIGNMENT

from . import langhelper as lh
_ = lh.CURRENT_GETTEXT

ImageFile.LOAD_TRUNCATED_IMAGES = True  # Prevents image truncation


def create_document(doc_full_filename: str, doc_template_filename: str, doc_data: DocData) -> bool:
    """ Generates a Word file based on a Word template

    :param doc_full_filename: Filename of the document to create
    :param doc_template_filename: The filename of the template file
    :param doc_data: Document data
    :return: Returns True if succeeded
    """
    check = False
    try:
        document = Document(doc_template_filename)

        # Get styles
        # ---------------------------------------------------------------------------
        # styles = document.styles
        # table_styles = [s for s in styles if s.type == WD_STYLE_TYPE.TABLE]
        # for style in table_styles:
        #     print(style.name)

        # Create pages:
        # ---------------------------------------------------------------------------
        for item in doc_data.data_items:
            check |= not _create_item_page(document, item)

        document.save(doc_full_filename)
        return not check
    except Exception as e:
        return False


def _create_item_page(document: Document, data_item: IDocDataItem) -> bool:
    """ Create a data item page

    :param document: The document to create
    :param data_item: doc data item to render
    :return: Returns True if succeeded
    """
    if document is None:
        return False
    try:
        # Page Break
        document.add_page_break()
        # Add a headline for the given data item:
        document.add_heading(data_item.get_displ_name(), 1)

        # Add screenshot if available:
        if data_item.img_file:
            document.add_picture(data_item.img_file, width=Inches(7))
            last_paragraph = document.paragraphs[-1]
            last_paragraph.alignment = WD_PARAGRAPH_ALIGNMENT.LEFT

        # Render data to document:
        data_item.render_data_to_doc(document)
    except Exception as e:
        return False
